import request from '@/utils/request'

// 查询区域列表列表
export function listPart(query) {
  return request({
    url: '/bst/part/list',
    method: 'get',
    params: query
  })
}

// 查询区域列表详细
export function getPart(partId) {
  return request({
    url: '/bst/part/' + partId,
    method: 'get'
  })
}

// 新增区域列表
export function addPart(data) {
  return request({
    url: '/bst/part',
    method: 'post',
    data: data
  })
}

// 修改区域列表
export function updatePart(data) {
  return request({
    url: '/bst/part',
    method: 'put',
    data: data
  })
}

// 删除区域列表
export function delPart(partId) {
  return request({
    url: '/bst/part/' + partId,
    method: 'delete'
  })
}
